@@ -1,5 +1,5 @@
 ;;; GnuTLS --- Guile bindings for GnuTLS.
-;;; Copyright (C) 2007-2012, 2014 Free Software Foundation, Inc.
+;;; Copyright (C) 2007-2012, 2014, 2015 Free Software Foundation, Inc.
 ;;;
 ;;; GnuTLS is free software; you can redistribute it and/or
 ;;; modify it under the terms of the GNU Lesser General Public
@@ -73,13 +73,7 @@
 
            ;; priorities
            set-session-priorities!
-
-           ;; priority functions (deprecated)
-           set-session-cipher-priority! set-session-mac-priority!
-           set-session-compression-method-priority!
-           set-session-kx-priority! set-session-protocol-priority!
-           set-session-certificate-type-priority!
-           set-session-default-priority! set-session-default-export-priority!
+           set-session-default-priority!
 
            ;; DH
            set-session-dh-prime-bits!
@@ -423,12 +417,13 @@
            openpgp-certificate-format/raw
            openpgp-certificate-format/base64))
 
-(define %libdir
-  (or (getenv "GNUTLS_GUILE_EXTENSION_DIR")
-      "/usr/lib/guile/1.8"))
+(eval-when (expand load eval)
+  (define %libdir
+    (or (getenv "GNUTLS_GUILE_EXTENSION_DIR")
+        "/usr/lib/guile/1.8"))
 
-(load-extension (string-append %libdir "/guile-gnutls-v-2")
-                "scm_init_gnutls")
+  (load-extension (string-append %libdir "/guile-gnutls-v-2")
+                  "scm_init_gnutls"))
 
 ;; Renaming.
 (define protocol/ssl-3 protocol/ssl3)
